@@ -105,6 +105,7 @@ pub struct TerminalPane {
     prev_pane_name: String,
     frame: HashMap<ClientId, PaneFrame>,
     borderless: bool,
+    exclude_from_sync: bool,
     fake_cursor_locations: HashSet<(usize, usize)>, // (x, y) - these hold a record of previous fake cursors which we need to clear on render
     search_term: String,
     is_held: Option<(Option<i32>, IsFirstRun, RunCommand)>, // a "held" pane means that its command has either exited and the pane is waiting for a
@@ -602,6 +603,14 @@ impl Pane for TerminalPane {
         self.borderless
     }
 
+    fn set_exclude_from_sync(&mut self, exclude_from_sync: bool) {
+        self.exclude_from_sync = exclude_from_sync;
+    }
+
+    fn exclude_from_sync(&self) -> bool {
+        self.exclude_from_sync
+    }
+
     fn mouse_left_click(&self, position: &Position, is_held: bool) -> Option<String> {
         self.grid.mouse_left_click_signal(position, is_held)
     }
@@ -711,6 +720,35 @@ impl Pane for TerminalPane {
     fn set_title(&mut self, title: String) {
         self.pane_title = title;
     }
+    fn current_title(&self) -> String {
+        if self.pane_name.is_empty() {
+            self.grid
+                .title
+                .as_deref()
+                .unwrap_or(&self.pane_title)
+                .into()
+        } else {
+            self.pane_name.to_owned()
+        }
+    }
+    fn exit_status(&self) -> Option<i32> {
+        self.is_held
+            .as_ref()
+            .and_then(|(exit_status, _, _)| *exit_status)
+    }
+    fn is_held(&self) -> bool {
+        self.is_held.is_some()
+    }
+    fn exited(&self) -> bool {
+        match self.is_held {
+            Some((_, is_first_run, _)) => !is_first_run,
+            None => false,
+        }
+    }
+    fn rename(&mut self, buf: Vec<u8>) {
+        self.pane_name = String::from_utf8_lossy(&buf).to_string();
+        self.set_should_render(true);
+    }
 }
 
 impl TerminalPane {
@@ -728,6 +766,7 @@ impl TerminalPane {
         terminal_emulator_color_codes: Rc<RefCell<HashMap<usize, String>>>,
         initial_pane_title: Option<String>,
         invoked_with: Option<Run>,
+        debug: bool,
     ) -> TerminalPane {
         let initial_pane_title =
             initial_pane_title.unwrap_or_else(|| format!("Pane #{}", pane_index));
@@ -739,6 +778,7 @@ impl TerminalPane {
             link_handler,
             character_cell_size,
             sixel_image_store,
+            debug,
         );
         TerminalPane {
             frame: HashMap::new(),
@@ -756,6 +796,7 @@ impl TerminalPane {
             pane_name: pane_name.clone(),
             prev_pane_name: pane_name,
             borderless: false,
+            exclude_from_sync: false,
             fake_cursor_locations: HashSet::new(),
             search_term: String::new(),
             is_held: None,
