@@ -2,7 +2,7 @@
 
 use super::command::RunCommandAction;
 use super::layout::{
-    FloatingPaneLayout, Layout, RunPluginLocation, SwapFloatingLayout, SwapTiledLayout,
+    FloatingPaneLayout, Layout, RunPlugin, RunPluginLocation, SwapFloatingLayout, SwapTiledLayout,
     TiledPaneLayout,
 };
 use crate::cli::CliAction;
@@ -204,6 +204,7 @@ pub enum Action {
     LeftClick(Position),
     RightClick(Position),
     MiddleClick(Position),
+    LaunchOrFocusPlugin(RunPlugin, bool), // bool => should float
     LeftMouseRelease(Position),
     RightMouseRelease(Position),
     MiddleMouseRelease(Position),
@@ -231,6 +232,14 @@ pub enum Action {
     /// Open a new tiled (embedded, non-floating) plugin pane
     NewTiledPluginPane(RunPluginLocation, Option<String>), // String is an optional name
     NewFloatingPluginPane(RunPluginLocation, Option<String>), // String is an optional name
+    StartOrReloadPlugin(RunPlugin),
+    CloseTerminalPane(u32),
+    ClosePluginPane(u32),
+    FocusTerminalPaneWithId(u32, bool), // bool is should_float_if_hidden
+    FocusPluginPaneWithId(u32, bool),   // bool is should_float_if_hidden
+    RenameTerminalPane(u32, Vec<u8>),
+    RenamePluginPane(u32, Vec<u8>),
+    RenameTab(u32, Vec<u8>),
 }
 
 impl Action {
@@ -284,14 +293,18 @@ impl Action {
                 close_on_exit,
                 start_suspended,
             } => {
+                let current_dir = get_current_dir();
+                let cwd = cwd
+                    .map(|cwd| current_dir.join(cwd))
+                    .or_else(|| Some(current_dir));
                 if let Some(plugin) = plugin {
                     if floating {
-                        let plugin = RunPluginLocation::parse(&plugin).map_err(|e| {
+                        let plugin = RunPluginLocation::parse(&plugin, cwd).map_err(|e| {
                             format!("Failed to parse plugin loction {plugin}: {}", e)
                         })?;
                         Ok(vec![Action::NewFloatingPluginPane(plugin, name)])
                     } else {
-                        let plugin = RunPluginLocation::parse(&plugin).map_err(|e| {
+                        let plugin = RunPluginLocation::parse(&plugin, cwd).map_err(|e| {
                             format!("Failed to parse plugin location {plugin}: {}", e)
                         })?;
                         // it is intentional that a new tiled plugin pane cannot include a
@@ -307,10 +320,6 @@ impl Action {
                 } else if !command.is_empty() {
                     let mut command = command.clone();
                     let (command, args) = (PathBuf::from(command.remove(0)), command);
-                    let current_dir = get_current_dir();
-                    let cwd = cwd
-                        .map(|cwd| current_dir.join(cwd))
-                        .or_else(|| Some(current_dir));
                     let hold_on_start = start_suspended;
                     let hold_on_close = !close_on_exit;
                     let run_command_action = RunCommandAction {
@@ -471,6 +480,26 @@ impl Action {
             CliAction::PreviousSwapLayout => Ok(vec![Action::PreviousSwapLayout]),
             CliAction::NextSwapLayout => Ok(vec![Action::NextSwapLayout]),
             CliAction::QueryTabNames => Ok(vec![Action::QueryTabNames]),
+            CliAction::StartOrReloadPlugin { url } => {
+                let current_dir = get_current_dir();
+                let run_plugin_location = RunPluginLocation::parse(&url, Some(current_dir))
+                    .map_err(|e| format!("Failed to parse plugin location: {}", e))?;
+                let run_plugin = RunPlugin {
+                    location: run_plugin_location,
+                    _allow_exec_host_cmd: false,
+                };
+                Ok(vec![Action::StartOrReloadPlugin(run_plugin)])
+            },
+            CliAction::LaunchOrFocusPlugin { url, floating } => {
+                let current_dir = get_current_dir();
+                let run_plugin_location = RunPluginLocation::parse(url.as_str(), Some(current_dir))
+                    .map_err(|e| format!("Failed to parse plugin location: {}", e))?;
+                let run_plugin = RunPlugin {
+                    location: run_plugin_location,
+                    _allow_exec_host_cmd: false,
+                };
+                Ok(vec![Action::LaunchOrFocusPlugin(run_plugin, floating)])
+            },
         }
     }
 }
