@@ -92,6 +92,7 @@ impl<'a> KdlLayoutParser<'a> {
             || property_name == "children"
             || property_name == "stacked"
             || property_name == "expanded"
+            || property_name == "exclude_from_sync"
     }
     fn is_a_valid_floating_pane_property(&self, property_name: &str) -> bool {
         property_name == "borderless"
@@ -296,13 +297,14 @@ impl<'a> KdlLayoutParser<'a> {
                 plugin_block.span().len(),
             ),
         )?;
-        let location = RunPluginLocation::parse(&string_url).map_err(|e| {
-            ConfigError::new_layout_kdl_error(
-                e.to_string(),
-                url_node.span().offset(),
-                url_node.span().len(),
-            )
-        })?;
+        let location =
+            RunPluginLocation::parse(&string_url, self.cwd_prefix(None)?).map_err(|e| {
+                ConfigError::new_layout_kdl_error(
+                    e.to_string(),
+                    url_node.span().offset(),
+                    url_node.span().len(),
+                )
+            })?;
         Ok(Some(Run::Plugin(RunPlugin {
             _allow_exec_host_cmd,
             location,
@@ -332,22 +334,27 @@ impl<'a> KdlLayoutParser<'a> {
             (None, None) => None,
         })
     }
-    fn parse_cwd(&self, kdl_node: &KdlNode) -> Result<Option<PathBuf>, ConfigError> {
-        Ok(
-            kdl_get_string_property_or_child_value_with_error!(kdl_node, "cwd")
-                .map(|cwd| PathBuf::from(cwd)),
-        )
+    fn parse_path(
+        &self,
+        kdl_node: &KdlNode,
+        name: &'static str,
+    ) -> Result<Option<PathBuf>, ConfigError> {
+        match kdl_get_string_property_or_child_value_with_error!(kdl_node, name) {
+            Some(s) => match shellexpand::full(s) {
+                Ok(s) => Ok(Some(PathBuf::from(s.as_ref()))),
+                Err(e) => Err(kdl_parsing_error!(e.to_string(), kdl_node)),
+            },
+            None => Ok(None),
+        }
     }
     fn parse_pane_command(
         &self,
         pane_node: &KdlNode,
         is_template: bool,
     ) -> Result<Option<Run>, ConfigError> {
-        let command = kdl_get_string_property_or_child_value_with_error!(pane_node, "command")
-            .map(|c| PathBuf::from(c));
-        let edit = kdl_get_string_property_or_child_value_with_error!(pane_node, "edit")
-            .map(|c| PathBuf::from(c));
-        let cwd = self.parse_cwd(pane_node)?;
+        let command = self.parse_path(pane_node, "command")?;
+        let edit = self.parse_path(pane_node, "edit")?;
+        let cwd = self.parse_path(pane_node, "cwd")?;
         let args = self.parse_args(pane_node)?;
         let close_on_exit =
             kdl_get_bool_property_or_child_value_with_error!(pane_node, "close_on_exit");
@@ -445,6 +452,8 @@ impl<'a> KdlLayoutParser<'a> {
         let focus = kdl_get_bool_property_or_child_value_with_error!(kdl_node, "focus");
         let name = kdl_get_string_property_or_child_value_with_error!(kdl_node, "name")
             .map(|name| name.to_string());
+        let exclude_from_sync =
+            kdl_get_bool_property_or_child_value_with_error!(kdl_node, "exclude_from_sync");
         let split_size = self.parse_split_size(kdl_node)?;
         let run = self.parse_command_plugin_or_edit_block(kdl_node)?;
         let children_split_direction = self.parse_split_direction(kdl_node)?;
@@ -483,6 +492,7 @@ impl<'a> KdlLayoutParser<'a> {
             run,
             children_split_direction,
             external_children_index,
+            exclude_from_sync,
             children,
             children_are_stacked,
             is_expanded_in_stack,
@@ -605,6 +615,8 @@ impl<'a> KdlLayoutParser<'a> {
                     kdl_get_bool_property_or_child_value_with_error!(kdl_node, "start_suspended");
                 let split_size = self.parse_split_size(kdl_node)?;
                 let run = self.parse_command_plugin_or_edit_block_for_template(kdl_node)?;
+                let exclude_from_sync =
+                    kdl_get_bool_property_or_child_value_with_error!(kdl_node, "exclude_from_sync");
 
                 let external_children_index = if should_mark_external_children_index {
                     self.populate_external_children_index(kdl_node)?
@@ -641,6 +653,9 @@ impl<'a> KdlLayoutParser<'a> {
                 if let Some(name) = name {
                     pane_template.name = Some(name);
                 }
+                if let Some(exclude_from_sync) = exclude_from_sync {
+                    pane_template.exclude_from_sync = Some(exclude_from_sync);
+                }
                 if let Some(split_size) = split_size {
                     pane_template.split_size = Some(split_size);
                 }
@@ -1038,8 +1053,7 @@ impl<'a> KdlLayoutParser<'a> {
         self.assert_valid_tab_properties(kdl_node)?;
         let tab_name =
             kdl_get_string_property_or_child_value!(kdl_node, "name").map(|s| s.to_string());
-        let tab_cwd =
-            kdl_get_string_property_or_child_value!(kdl_node, "cwd").map(|c| PathBuf::from(c));
+        let tab_cwd = self.parse_path(kdl_node, "cwd")?;
         let is_focused = kdl_get_bool_property_or_child_value!(kdl_node, "focus").unwrap_or(false);
         let children_split_direction = self.parse_split_direction(kdl_node)?;
         let mut child_floating_panes = vec![];
@@ -1365,8 +1379,7 @@ impl<'a> KdlLayoutParser<'a> {
     ) -> Result<(), ConfigError> {
         let has_borderless_prop =
             kdl_get_bool_property_or_child_value_with_error!(kdl_node, "borderless").is_some();
-        let has_cwd_prop =
-            kdl_get_string_property_or_child_value_with_error!(kdl_node, "cwd").is_some();
+        let has_cwd_prop = self.parse_path(kdl_node, "cwd")?.is_some();
         let has_non_cwd_run_prop = self
             .parse_command_plugin_or_edit_block(kdl_node)?
             .map(|r| match r {
@@ -1436,8 +1449,7 @@ impl<'a> KdlLayoutParser<'a> {
         // (is_focused, Option<tab_name>, PaneLayout, Vec<FloatingPaneLayout>)
         let tab_name =
             kdl_get_string_property_or_child_value!(kdl_node, "name").map(|s| s.to_string());
-        let tab_cwd =
-            kdl_get_string_property_or_child_value!(kdl_node, "cwd").map(|c| PathBuf::from(c));
+        let tab_cwd = self.parse_path(kdl_node, "cwd")?;
         let is_focused = kdl_get_bool_property_or_child_value!(kdl_node, "focus").unwrap_or(false);
         let children_split_direction = self.parse_split_direction(kdl_node)?;
         match kdl_children_nodes!(kdl_node) {
@@ -1670,11 +1682,7 @@ impl<'a> KdlLayoutParser<'a> {
     fn populate_global_cwd(&mut self, layout_node: &KdlNode) -> Result<(), ConfigError> {
         // we only populate global cwd from the layout file if another wasn't explicitly passed to us
         if self.global_cwd.is_none() {
-            if let Some(global_cwd) =
-                kdl_get_string_property_or_child_value_with_error!(layout_node, "cwd")
-            {
-                self.global_cwd = Some(PathBuf::from(global_cwd));
-            }
+            self.global_cwd = self.parse_path(layout_node, "cwd")?;
         }
         Ok(())
     }
@@ -1971,7 +1979,7 @@ impl<'a> KdlLayoutParser<'a> {
             .unwrap_or_else(|| TiledPaneLayout::default());
 
         Ok(Layout {
-            tabs: tabs,
+            tabs,
             template: Some((template, vec![])),
             focused_tab_index,
             swap_tiled_layouts,
