@@ -10,8 +10,6 @@ use crate::input::theme::{FrameConfig, Theme, Themes, UiConfig};
 use crate::setup::{find_default_config_dir, get_layout_dir};
 use kdl_layout_parser::KdlLayoutParser;
 use std::collections::HashMap;
-use std::fs::File;
-use std::io::Read;
 use strum::IntoEnumIterator;
 
 use miette::NamedSource;
@@ -878,6 +876,30 @@ impl TryFrom<(&KdlNode, &Options)> for Action {
                 };
                 Ok(Action::Run(run_command_action))
             },
+            "LaunchOrFocusPlugin" => {
+                let arguments = action_arguments.iter().copied();
+                let mut args = kdl_arguments_that_are_strings(arguments)?;
+                if args.is_empty() {
+                    return Err(ConfigError::new_kdl_error(
+                        "No plugin found to launch in LaunchOrFocusPlugin".into(),
+                        kdl_action.span().offset(),
+                        kdl_action.span().len(),
+                    ));
+                }
+                let plugin_path = args.remove(0);
+
+                let command_metadata = action_children.iter().next();
+                let should_float = command_metadata
+                    .and_then(|c_m| kdl_child_bool_value_for_entry(c_m, "floating"))
+                    .unwrap_or(false);
+                let current_dir = std::env::current_dir().unwrap_or_else(|_| PathBuf::from("."));
+                let location = RunPluginLocation::parse(&plugin_path, Some(current_dir))?;
+                let run_plugin = RunPlugin {
+                    location,
+                    _allow_exec_host_cmd: false,
+                };
+                Ok(Action::LaunchOrFocusPlugin(run_plugin, should_float))
+            },
             "PreviousSwapLayout" => Ok(Action::PreviousSwapLayout),
             "NextSwapLayout" => Ok(Action::NextSwapLayout),
             _ => Err(ConfigError::new_kdl_error(
@@ -1304,6 +1326,8 @@ impl Options {
         let default_shell =
             kdl_property_first_arg_as_string_or_error!(kdl_options, "default_shell")
                 .map(|(string, _entry)| PathBuf::from(string));
+        let default_cwd = kdl_property_first_arg_as_string_or_error!(kdl_options, "default_cwd")
+            .map(|(string, _entry)| PathBuf::from(string));
         let pane_frames =
             kdl_property_first_arg_as_bool_or_error!(kdl_options, "pane_frames").map(|(v, _)| v);
         let auto_layout =
@@ -1358,6 +1382,7 @@ impl Options {
             theme,
             default_mode,
             default_shell,
+            default_cwd,
             default_layout,
             layout_dir,
             theme_dir,
@@ -1378,7 +1403,7 @@ impl Options {
 }
 
 impl RunPlugin {
-    pub fn from_kdl(kdl_node: &KdlNode) -> Result<Self, ConfigError> {
+    pub fn from_kdl(kdl_node: &KdlNode, cwd: Option<PathBuf>) -> Result<Self, ConfigError> {
         let _allow_exec_host_cmd =
             kdl_get_child_entry_bool_value!(kdl_node, "_allow_exec_host_cmd").unwrap_or(false);
         let string_url = kdl_get_child_entry_string_value!(kdl_node, "location").ok_or(
@@ -1388,7 +1413,7 @@ impl RunPlugin {
                 kdl_node.span().len(),
             ),
         )?;
-        let location = RunPluginLocation::parse(string_url).map_err(|e| {
+        let location = RunPluginLocation::parse(string_url, cwd).map_err(|e| {
             ConfigError::new_layout_kdl_error(
                 e.to_string(),
                 kdl_node.span().offset(),
@@ -1743,9 +1768,8 @@ impl Themes {
 
     pub fn from_path(path_to_theme_file: PathBuf) -> Result<Self, ConfigError> {
         // String is the theme name
-        let mut file = File::open(path_to_theme_file.clone())?;
-        let mut kdl_config = String::new();
-        file.read_to_string(&mut kdl_config)?;
+        let kdl_config = std::fs::read_to_string(&path_to_theme_file)
+            .map_err(|e| ConfigError::IoPath(e, path_to_theme_file.into()))?;
         let kdl_config: KdlDocument = kdl_config.parse()?;
         let kdl_themes = kdl_config.get("themes").ok_or(ConfigError::new_kdl_error(
             "No theme node found in file".into(),
@@ -1755,4 +1779,20 @@ impl Themes {
         let all_themes_in_file = Themes::from_kdl(kdl_themes)?;
         Ok(all_themes_in_file)
     }
+
+    pub fn from_dir(path_to_theme_dir: PathBuf) -> Result<Self, ConfigError> {
+        let mut themes = Themes::default();
+        for entry in std::fs::read_dir(&path_to_theme_dir)
+            .map_err(|e| ConfigError::IoPath(e, path_to_theme_dir.clone()))?
+        {
+            let entry = entry.map_err(|e| ConfigError::IoPath(e, path_to_theme_dir.clone()))?;
+            let path = entry.path();
+            if let Some(extension) = path.extension() {
+                if extension == "kdl" {
+                    themes = themes.merge(Themes::from_path(path)?);
+                }
+            }
+        }
+        Ok(themes)
+    }
 }
